/**
 * Copyright (c) 2021, WSO2 Inc. (http://www.wso2.com). All Rights Reserved.
 *
 * This software is the property of WSO2 Inc. and its suppliers, if any.
 * Dissemination of any information or reproduction of any material contained
 * herein in any form is strictly forbidden, unless permitted by WSO2 expressly.
 * You may not alter or remove any copyright or other notice from copies of this content."
 */

import { Extensions } from "../../models";
export const extensions: Extensions = {
    common: {
        help: {
            docSiteLink: "Go to Documentation",
            helpCenterLink: "Contact Support"
        },
    },
    console: {
        application: {
            quickStart: {
                technologySelectionWrapper: {
                    subHeading: "You can find the server endpoint details in the <1>Info section</1> to configure "
                        + "your application."
                },
                addUserOption:{
                    description: "You need a <1>customer user</1> account to login to the application.",
                    hint: "If you do not have a customer user account, click the button below to add one. " +
                        "Alternatively, you can manually add a customer user by navigating to " +
                        "<1>user management</1>.",
                    message: "If you do not already have a customer user account, contact your organization " +
                        "administrator."
                }
            }
        }
    },
    develop: {
        applications: {
            edit: {
                sections: {
                    signInMethod: {
                        sections: {
                            authenticationFlow: {
                                sections: {
                                    stepBased: {
                                        secondFactorDisabled: "Second factor authenticators can only be used if " +
                                            "<1>Username & Password</1> is present in a previous step."
                                    }
                                }
                            }
                        }
                    }
                }
            }
        },
        identityProviders: {
            facebook: {
                quickStart: {
                    addLoginModal: {
                        heading: "Add Facebook Login",
                        subHeading: "Select an application to set up Facebook login."
                    },
                    connectApp: {
                        description: "Add <1>Facebook</1> authenticator to <3>Step 1</3> on the <5>Sign-in Method" +
                            "</5> section of your <7>application</7>."
                    },
                    heading: "Add Facebook Login",
                    subHeading: "Facebook identity provider is now ready to be used as a login option for your " +
                        "applications."
                }
            },
            github: {
                quickStart: {
                    addLoginModal: {
                        heading: "Add GitHub Login",
                        subHeading: "Select an application to set up GitHub login."
                    },
                    connectApp: {
                        description: "Add <1>GitHub</1> authenticator to <3>Step 1</3> on the <5>Sign-in Method" +
                            "</5> section of your <7>application</7>."
                    },
                    heading: "Add GitHub Login",
                    subHeading: "GitHub identity provider is now ready to be used as a login option for your " +
                        "applications."
                }
            },
            google: {
                quickStart: {
                    addLoginModal: {
                        heading: "Add Google Login",
                        subHeading: "Select an application to set up Google login."
                    },
                    connectApp: {
                        description: "Add <1>Google</1> authenticator to <3>Step 1</3> on the <5>Sign-in Method" +
                            "</5> section of your <7>application</7>."
                    },
                    heading: "Add Google Login",
                    subHeading: "Google identity provider is now ready to be used as a login option for your " +
                        "applications."
                }
            }
        }
    },
    manage: {
        attributes: {
            attributes: {
                description: "View and manage attributes"
            }
        },
        features: {
            tenant: {
                header: {
                    tenantSwitchHeader: "Switch Organization",
                    tenantAddHeader: "New Organization",
                    tenantDefaultButton: "Default",
                    tenantMakeDefaultButton: "Make default",
                    backButton: "Go back",
                    tenantSearch: {
                        placeholder: "Search organization",
                        emptyResultMessage: "No organizations found"
                    }
                },
                wizards: {
                    addTenant: {
                        heading: "Add New Organization",
                        forms: {
                            fields: {
                                tenantName: {
                                    label: "Organization Name",
                                    placeholder: "Organization name (E.g., myorg)",
                                    validations: {
                                        empty: "This is a required field.",
                                        duplicate: "An organization with the name {{ tenantName }} already exists." +
                                            " Please try a different name.",
                                        invalid: "The name you entered contains disallowed characters. It can" +
                                            " contain up to {{ characterLimit }} characters, can only consist of" +
                                            " lowercase alphanumerics and it must always begin with an alphabet" +
                                            " character.",
                                        invalidLength: "The name you entered is less than {{ characterLowerLimit }}" +
                                            " characters. It can contain up to {{ characterLimit }} characters," +
                                            " can only consist of lowercase alphanumerics and it must always begin" +
                                            " with an alphabet character."
                                    }
                                }
                            },
                            loaderMessages: {
                                duplicateCheck: "Validating new organization name...",
                                tenantCreate: "Creating the new organization...",
                                tenantSwitch: "Please wait while we redirect you to the new organization..."
                            },
                            messages: {
                                info: "Think of a good, unique organization name for your new Asgardeo workspace" +
                                    " because you won’t be able to change it later!"
                            }
                        },
                        tooltips: {
                            message: "You will use this URL to access the new organization."
                        }
                    }
                },
                notifications: {
                    addTenant: {
                        error: {
                            description: "{{ description }}",
                            message: "Error Creating Organization"
                        },
                        genericError: {
                            description: "An error occurred while creating the organization.",
                            message: "Error Creating Organization"
                        },
                        limitReachError: {
                            description: "Maximum number of allowed organizations have been reached.",
                            message: "Error Creating Organization"
                        },
                        success: {
                            description: "Successfully created organization {{ tenantName }}.",
                            message: "Organization Created"
                        }
                    },
                    defaultTenant: {
                        genericError: {
                            description: "An error occurred while updating your default organization.",
                            message: "Error Updating Organization"
                        },
                        success: {
                            description: "Successfully set {{ tenantName }} as your default organization.",
                            message: "Updated Default Organization"
                        }
                    },
                    missingClaims: {
                        message: "Some personal info is missing",
                        description: "Please visit the MyAccount application and make sure that your first name," +
                            " last name and primary email have been set in the Personal Info section."
                    },
                    getTenants: {
                        message: "Unable to fetch your organizations",
                        description: "An error occurred while fetching your organizations."
                    }
                }
            }
        },
        groups: {
            edit: {
                users: {
                    heading: "Users in the Group",
                    description: "Add or remove users belonging to this group."
                }
            }
        },
        serverConfigurations: {
            accountManagement: {
                accountRecovery: {
                    heading: "Password Recovery",
                    subHeading: "Configure settings for self-service password recovery to let users " +
                        "reset their password using an email.",
                    toggleName: "Enable password recovery"
                }
            },
            additionalSettings: "Additional Settings",
            userOnboarding: {
                selfRegistration: {
                    backButton: "Go back to {{name}}",
                    backButtonAlternative: "Go back",
                    form: {
                        fields: {
                            enable: {
                                label: "Enable",
                                hint: "Allow consumer users to self sign-up for this organization. " +
                                    "When enabled, users will see a link to create an account at the login screen."
                            },
                            expiryTime: {
                                label: "Verification link expiry time"
                            },
                            signUpConfirmation: {
                                label: "Send sign up confirmation email",
                                hint: "After the user is registered, an account confirmation request is sent to " +
                                    "the user via email. The new account is activated only after the user confirms."
                            },
                        }
                    }
                }
            }
        },
        users: {
            editUserProfile: {
                disclaimerMessage: "This user profile belongs to a collaborator or an organization owner. Only the" +
                    " account owner can manage the profile via the My Account app."
            },
            list: {
                columns: {
                    user: "User",
                    accountType: "Account Type",
                    source: "Source"
                },
                popups: {
                    content: {
                        AccountTypeContent: "User's relation to this organization.",
                        sourceContent: "Where user is managed."
                    }
                }
            },
            notifications: {
                addUser: {
                    customerUser: {
                        limitReachError: {
                            description: "Maximum number of allowed customer users have been reached.",
                            message: "Error adding the new user"
                        }
                    }
                }
            }
        },
        invite: {
            notifications: {
                sendInvite: {
                    limitReachError: {
                        description: "Maximum number of allowed collaborator users have been reached.",
                        message: "Error while sending the invitation"
                    }
                }
            }
        }
    }
};
